@@ -176,6 +176,12 @@ pub enum PlotType {
     Surface,
 }
 
+impl Default for PlotType {
+    fn default() -> Self {
+        PlotType::Scatter
+    }
+}
+
 #[derive(Serialize, Debug)]
 pub enum Mode {
     #[serde(rename = "lines")]
@@ -616,23 +622,7 @@ pub struct Line {
 
 impl Line {
     pub fn new() -> Line {
-        Line {
-            width: None,
-            shape: None,
-            smoothing: None,
-            dash: None,
-            simplify: None,
-            color: None,
-            cauto: None,
-            cmin: None,
-            cmax: None,
-            cmid: None,
-            color_scale: None,
-            auto_color_scale: None,
-            reverse_scale: None,
-            outlier_color: None,
-            outlier_width: None,
-        }
+        Default::default()
     }
 
     pub fn width(mut self, width: f64) -> Line {
@@ -934,9 +924,7 @@ impl Default for ColorBar {
 impl ColorBar {
     pub fn new() -> ColorBar {
         ColorBar {
-            thickness_mode: None,
             thickness: 30,
-            len_mode: None,
             len: 1,
             x: 1.02,
             x_anchor: Anchor::Left,
@@ -944,34 +932,14 @@ impl ColorBar {
             y: 0.5,
             y_anchor: Anchor::Middle,
             y_pad: 10.0,
-            outline_color: None,
             outline_width: 1,
-            border_color: None,
             border_width: 0,
-            background_color: None,
-            tick_mode: None,
             n_ticks: 0,
-            tick0: None,
-            dtick: None,
-            tick_vals: None,
-            tick_text: None,
-            ticks: None,
             tick_len: 5,
             tick_width: 1,
-            tick_color: None,
             show_tick_labels: true,
-            tick_font: None,
-            tick_angle: None,
-            tick_format: None,
-            tick_format_stops: None,
-            tick_prefix: None,
-            show_tick_prefix: None,
-            tick_suffix: None,
-            show_tick_suffix: None,
             separate_thousands: true,
-            exponent_format: None,
-            show_exponent: None,
-            title: None,
+            ..Default::default()
         }
     }
 
@@ -1212,28 +1180,7 @@ pub struct Marker {
 
 impl Marker {
     pub fn new() -> Marker {
-        Marker {
-            symbol: None,
-            opacity: None,
-            size: None,
-            max_displayed: None,
-            size_ref: None,
-            size_min: None,
-            size_mode: None,
-            line: None,
-            gradient: None,
-            color: None,
-            cauto: None,
-            cmin: None,
-            cmax: None,
-            cmid: None,
-            color_scale: None,
-            auto_color_scale: None,
-            reverse_scale: None,
-            show_scale: None,
-            color_bar: None,
-            outlier_color: None,
-        }
+        Default::default()
     }
 
     pub fn symbol(mut self, symbol: MarkerSymbol) -> Marker {
@@ -1360,11 +1307,7 @@ pub struct Font {
 
 impl Font {
     pub fn new() -> Font {
-        Font {
-            family: None,
-            size: None,
-            color: None,
-        }
+        Default::default()
     }
 
     pub fn family(mut self, family: &str) -> Font {
@@ -1418,7 +1361,7 @@ impl Pad {
     }
 }
 
-#[derive(Serialize, Debug)]
+#[derive(Serialize, Debug, Default)]
 pub struct Title {
     text: String,
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -1441,19 +1384,17 @@ pub struct Title {
     pad: Option<Pad>,
 }
 
+impl From<&str> for Title {
+    fn from(title: &str) -> Self {
+        Title::new(title)
+    }
+}
+
 impl Title {
     pub fn new(text: &str) -> Title {
         Title {
             text: text.to_owned(),
-            font: None,
-            side: None,
-            x_ref: None,
-            y_ref: None,
-            x: None,
-            y: None,
-            x_anchor: None,
-            y_anchor: None,
-            pad: None,
+            ..Default::default()
         }
     }
 
@@ -1519,13 +1460,7 @@ pub struct Label {
 
 impl Label {
     pub fn new() -> Label {
-        Label {
-            background_color: None,
-            border_color: None,
-            font: None,
-            align: None,
-            name_length: None,
-        }
+        Default::default()
     }
 
     pub fn background_color<C: Color>(mut self, background_color: C) -> Label {
@@ -1571,7 +1506,13 @@ pub enum ErrorType {
     Data,
 }
 
-#[derive(Serialize, Debug)]
+impl Default for ErrorType {
+    fn default() -> Self {
+        ErrorType::Percent
+    }
+}
+
+#[derive(Serialize, Debug, Default)]
 pub struct ErrorData {
     r#type: ErrorType,
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -1604,18 +1545,7 @@ impl ErrorData {
     pub fn new(error_type: ErrorType) -> ErrorData {
         ErrorData {
             r#type: error_type,
-            array: None,
-            visible: None,
-            symmetric: None,
-            array_minus: None,
-            value: None,
-            value_minus: None,
-            trace_ref: None,
-            trace_ref_minus: None,
-            copy_ystyle: None,
-            color: None,
-            thickness: None,
-            width: None,
+            ..Default::default()
         }
     }
 
